'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parser = parser;
exports.compile = compile;
exports.transform = transform;

var _defaultsDeep = require('lodash/defaultsDeep');

var _defaultsDeep2 = _interopRequireDefault(_defaultsDeep);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function parser(code, asset) {
  return compile(code, {
    id: asset.id,
    asset: asset,
    project: asset.project
  });
}

function compile(code, options) {
  return transform(code, options).code;
}

function transform(code, options) {
  var id = options.id;

  var babel = require('babel-core');
  var skypagerPreset = attemptRequire($skypager && $skypager.babelPresetSkypager || 'babel-preset-skypager');

  var presets = [];

  if (skypagerPreset) {
    presets.push(skypagerPreset);
  }

  try {
    return babel.transform(code, {
      presets: presets
    });
  } catch (error) {
    return {
      ast: {},
      code: 'console.log(\'Error while compiling ' + id + '\', ' + error.message + ')',
      map: ''
    };
  }
}

function attemptRequire(moduleId) {
  try {
    return require(moduleId);
  } catch (error) {}
}